@@ -6,10 +6,8 @@
  *	create_adjust_popup()
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <Xm/Xm.h>
 #include <Xm/DialogS.h>
@@ -26,8 +24,10 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-static void done_callback(), guess_callback(),
-	    adjust_callback(), dst_callback();
+static void done_callback  (Widget, int, XmToggleButtonCallbackStruct *);
+static void guess_callback (Widget, int, XmToggleButtonCallbackStruct *);
+static void dst_callback   (Widget, int, XmToggleButtonCallbackStruct *);
+static void adjust_callback(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -45,9 +45,10 @@ static XtIntervalId	timer_id;	/* identifies 1-second timer */
 static Widget		time_w;		/* current time display */
 static Widget		adjust_w;	/* time adjustment text widget */
 static Widget		tzone_w;	/* timezone text widget */
-static Widget		toggle0_w;	/* top radio button for dst on */
-static Widget		toggle1_w;	/* middle radio button for dst off */
-static Widget		toggle2_w;	/* bottom radio button for auto dst */
+static Widget		toggle0_w;	/* radio button for dst on */
+static Widget		toggle1_w;	/* radio button for dst off */
+static Widget		toggle2_w;	/* radio button for auto dst */
+static Widget		toggle3_w;	/* radio button for system dst */
 static Widget		begin_w;	/* daylight saving begin text widget */
 static Widget		end_w;		/* daylight saving end text widget */
 
@@ -56,7 +57,7 @@ static Widget		end_w;		/* daylight saving end text widget */
  * print current time, once a second and when a button is pressed
  */
 
-static void print_times()
+static void print_times(void)
 {
 	int			hour, min, sec;
 
@@ -80,9 +81,9 @@ static void print_times()
 }
 
 /*ARGSUSED*/
-static void sec_timer_callback(data, id)
-	XtPointer		data;		/* not used */
-	XtIntervalId		*id;		/* not used */
+static void sec_timer_callback(
+	XtPointer		data,		/* not used */
+	XtIntervalId		*id)		/* not used */
 {
 	if (have_shell) {
 		print_times();
@@ -95,7 +96,7 @@ static void sec_timer_callback(data, id)
  * print text into all text widgets
  */
 
-static void print_text_buttons()
+static void print_text_buttons(void)
 {
 	Arg			args;
 	time_t			t;
@@ -128,7 +129,7 @@ static void print_text_buttons()
  * retrieve texts from text widgets, store everything in config
  */
 
-static void eval_menu_texts()
+static void eval_menu_texts(void)
 {
 	char		*string;	/* contents of text widget */
 
@@ -161,7 +162,7 @@ static void eval_menu_texts()
  * It's too much trouble to keep them for next time.
  */
 
-void destroy_adjust_popup()
+void destroy_adjust_popup(void)
 {
 	if (have_shell) {
 		eval_menu_texts();
@@ -180,7 +181,7 @@ void destroy_adjust_popup()
  * initialized with data from config.
  */
 
-void create_adjust_popup()
+void create_adjust_popup(void)
 {
 	Widget			form, frame, form2, form3, radio, w, w2;
 	Arg			args[20];
@@ -192,8 +193,8 @@ void create_adjust_popup()
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmDO_NOTHING);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("Adjust Time", applicationShellWidgetClass,
-				   toplevel, args, n);
+	shell = XtCreatePopupShell(_("Adjust Time"),
+			applicationShellWidgetClass, toplevel, args, n);
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
  			_XEditResCheckMessages, NULL);
@@ -201,7 +202,8 @@ void create_adjust_popup()
 	set_icon(shell, 1);
 	form = XtCreateManagedWidget("adjform1", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback,help_callback,(XtPointer)"adj");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"adj");
 
 							/*-- current time --*/
 	n = 0;
@@ -225,14 +227,14 @@ void create_adjust_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("adjform2", xmFormWidgetClass,
 			frame, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback, help_callback,
-							(XtPointer)"adj_time");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"adj_time");
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNtopOffset,		12);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	w = XtCreateManagedWidget("Add", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Add"), xmLabelWidgetClass,
 			form2, args, n);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -249,16 +251,16 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	adjust_w = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(adjust_w, XmNactivateCallback, adjust_callback,
-							(XtPointer)NULL);
+	XtAddCallback(adjust_w, XmNactivateCallback, (XtCallbackProc)
+			adjust_callback, (XtPointer)NULL);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNtopOffset,		12);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	adjust_w);		n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	w = XtCreateManagedWidget("(h:m:s) to system time", xmLabelWidgetClass,
-			form2, args, n);
+	w = XtCreateManagedWidget(_("(h:m:s) to system time"),
+			xmLabelWidgetClass, form2, args, n);
 							/*-- adjust tzone --*/
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -273,17 +275,18 @@ void create_adjust_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("adjform3", xmFormWidgetClass,
 			frame, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback, help_callback,
-							(XtPointer)"adj_dst");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"adj_dst");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNtopOffset,		8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	w2 = XtCreateManagedWidget("Timezone is GMT", xmLabelWidgetClass,
+	w2 = XtCreateManagedWidget(_("Timezone is GMT"), xmLabelWidgetClass,
 			form2, args, n);
-	XtAddCallback(w2, XmNhelpCallback,help_callback,(XtPointer)"adj_zone");
+	XtAddCallback(w2, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"adj_zone");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -298,15 +301,15 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	tzone_w = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(tzone_w, XmNactivateCallback, adjust_callback,
-							(XtPointer)NULL);
+	XtAddCallback(tzone_w, XmNactivateCallback, (XtCallbackProc)
+			adjust_callback, (XtPointer)NULL);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNtopOffset,		8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	tzone_w);		n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	w = XtCreateManagedWidget("(h:m)", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("(h:m)"), xmLabelWidgetClass,
 			form2, args, n);
 							/*-- dst radio --*/
 	n = 0;
@@ -320,7 +323,7 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNtopOffset,		24);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	w = XtCreateManagedWidget("Daylight Saving is", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Daylight Saving is"), xmLabelWidgetClass,
 			form3, args, n);
 
 	n = 0;
@@ -337,32 +340,42 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNindicatorType,	XmONE_OF_MANY);		n++;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	XtSetArg(args[n], XmNset,		config.dst_flag==0);	n++;
-	toggle0_w = XtCreateManagedWidget("always on",
+	XtSetArg(args[n], XmNset,		config.dst_flag==3);	n++;
+	toggle3_w = XtCreateManagedWidget(_("use system time"),
 			xmToggleButtonWidgetClass,
 			radio, args, n);
-	XtAddCallback(toggle0_w, XmNvalueChangedCallback, dst_callback,
-								(XtPointer)0);
+	XtAddCallback(toggle3_w, XmNvalueChangedCallback, (XtCallbackProc)
+			dst_callback, (XtPointer)3);
+	n = 0;
+	XtSetArg(args[n], XmNindicatorType,	XmONE_OF_MANY);		n++;
+	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
+	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
+	XtSetArg(args[n], XmNset,		config.dst_flag==0);	n++;
+	toggle0_w = XtCreateManagedWidget(_("always on"),
+			xmToggleButtonWidgetClass,
+			radio, args, n);
+	XtAddCallback(toggle0_w, XmNvalueChangedCallback, (XtCallbackProc)
+			dst_callback, (XtPointer)0);
 	n = 0;
 	XtSetArg(args[n], XmNindicatorType,	XmONE_OF_MANY);		n++;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.dst_flag==1);	n++;
-	toggle1_w = XtCreateManagedWidget("always off",
+	toggle1_w = XtCreateManagedWidget(_("always off"),
 			xmToggleButtonWidgetClass,
 			radio, args, n);
-	XtAddCallback(toggle1_w, XmNvalueChangedCallback, dst_callback,
-								(XtPointer)1);
+	XtAddCallback(toggle1_w, XmNvalueChangedCallback, (XtCallbackProc)
+			dst_callback, (XtPointer)1);
 	n = 0;
 	XtSetArg(args[n], XmNindicatorType,	XmONE_OF_MANY);		n++;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.dst_flag==2);	n++;
-	toggle2_w = XtCreateManagedWidget("automatic",
+	toggle2_w = XtCreateManagedWidget(_("automatic"),
 			xmToggleButtonWidgetClass,
 			radio, args, n);
-	XtAddCallback(toggle2_w, XmNvalueChangedCallback, dst_callback,
-								(XtPointer)2);
+	XtAddCallback(toggle2_w, XmNvalueChangedCallback, (XtCallbackProc)
+			dst_callback, (XtPointer)2);
 
 							/*-- dst day range --*/
 	n = 0;
@@ -371,7 +384,7 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNtopOffset,		24);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	w = XtCreateManagedWidget("Automatic DST from Julian day",
+	w = XtCreateManagedWidget(_("Automatic DST from Julian day"),
 			xmLabelWidgetClass,
 			form2, args, n);
 
@@ -389,8 +402,8 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	begin_w = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(begin_w, XmNactivateCallback, adjust_callback,
-							(XtPointer)NULL);
+	XtAddCallback(begin_w, XmNactivateCallback, (XtCallbackProc)
+			adjust_callback, (XtPointer)NULL);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		form3);			n++;
@@ -398,7 +411,7 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	begin_w);		n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	w = XtCreateManagedWidget("to", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("to"), xmLabelWidgetClass,
 			form2, args, n);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -418,8 +431,8 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	end_w = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(end_w, XmNactivateCallback, adjust_callback,
-							(XtPointer)NULL);
+	XtAddCallback(end_w, XmNactivateCallback, (XtCallbackProc)
+			adjust_callback, (XtPointer)NULL);
 
 							/*-- buttons --*/
 	n = 0;
@@ -431,10 +444,12 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,(XtPointer)"adj_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"adj_done");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -446,10 +461,12 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, help_callback, (XtPointer)"adj");
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)"adj");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"adj");
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"adj");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -461,10 +478,12 @@ void create_adjust_popup()
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Guess", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Guess"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, guess_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,help_callback,(XtPointer)"adj_guess");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			guess_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"adj_guess");
 
 	XtManageChild(radio);
 	XtPopup(shell, XtGrabNone);
@@ -472,8 +491,8 @@ void create_adjust_popup()
 	print_times();
 
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
 	have_shell = TRUE;
 	timer_id = XtAppAddTimeOut(app, 1000, sec_timer_callback, 0);
 }
@@ -485,20 +504,20 @@ void create_adjust_popup()
  */
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_adjust_popup();
 }
 
 
 /*ARGSUSED*/
-static void guess_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void guess_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	Arg				args;
 
@@ -507,6 +526,7 @@ static void guess_callback(widget, item, data)
 	XtSetArg(args, XmNset, FALSE);
 	XtSetValues(toggle0_w, &args, 1);
 	XtSetValues(toggle1_w, &args, 1);
+	XtSetValues(toggle3_w, &args, 1);
 	XtSetArg(args, XmNset, TRUE);
 	XtSetValues(toggle2_w, &args, 1);
 	print_text_buttons();
@@ -515,22 +535,24 @@ static void guess_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void dst_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void dst_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
-	config.dst_flag = item;
-	print_text_buttons();
-	print_times();
+	if (data->set) {
+		config.dst_flag = item;
+		print_text_buttons();
+		print_times();
+	}
 }
 
 
 /*ARGSUSED*/
-static void adjust_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void adjust_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	eval_menu_texts();
 	print_text_buttons();
