@@ -26,7 +26,8 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-static void		flag_callback(), done_callback();
+static void flag_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -38,6 +39,7 @@ extern struct mainmenu	mainmenu;	/* all important main window widgets */
 static BOOL		have_shell;	/* message popup exists if TRUE */
 static Widget		shell;		/* popup menu shell */
 static Widget		ndays;		/* # of days in week text widgets */
+static Widget		defwarn;	/* default warning string */
 static Widget		min, max;	/* min and max hour text widgets */
 
 
@@ -46,16 +48,22 @@ static Widget		min, max;	/* min and max hour text widgets */
  * It's too much trouble to keep them for next time.
  */
 
-void destroy_calconfig_popup()
+void destroy_calconfig_popup(void)
 {
 	char			*string;	/* contents of text widget */
 	int			n, b, e;
+	BOOL			dummy;
 
 	if (have_shell) {
 		string = XmTextFieldGetString(ndays);
 		n = atoi(string);
 		XtFree(string);
 
+		string = XmTextFieldGetString(defwarn);
+		parse_warnstring(string, &config.early_time,
+					 &config.late_time, &dummy);
+		XtFree(string);
+
 		string = XmTextFieldGetString(min);
 		b = atoi(string);
 		XtFree(string);
@@ -77,6 +85,7 @@ void destroy_calconfig_popup()
 		XTDESTROYWIDGET(shell);
 		have_shell = FALSE;
 		mainlist->modified = TRUE;
+		write_mainlist();
 		draw_week_calendar(NULL);
 		draw_day_calendar(NULL);
 	}
@@ -88,11 +97,11 @@ void destroy_calconfig_popup()
  * popup is initialized with data from config.
  */
 
-void create_calconfig_popup()
+void create_calconfig_popup(void)
 {
-	Widget			root, scroll, form, frame, form2, w, help;
+	Widget			root, scroll, form, frame, form2, w, w2, help;
 	Arg			args[20];
-	int			n;
+	int			n, a, b;
 	Atom			closewindow;
 	Dimension		xs=0, ys=0;
 
@@ -101,7 +110,7 @@ void create_calconfig_popup()
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmDO_NOTHING);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("Calendar view configuration",
+	shell = XtCreatePopupShell(_("Calendar view configuration"),
 			applicationShellWidgetClass, toplevel, args, n);
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
@@ -119,8 +128,8 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNscrollingPolicy,	XmVARIABLE);		n++;
 	scroll = XtCreateManagedWidget("scroll", xmScrolledWindowWidgetClass,
 			root, args, n);
-	XtAddCallback(scroll, XmNhelpCallback, help_callback,
-						(XtPointer)"calconfig");
+	XtAddCallback(scroll, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"calconfig");
 	form = XtCreateManagedWidget("rangeform0", xmFormWidgetClass,
 			scroll, NULL, 0);
 
@@ -131,11 +140,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"range_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer) "range_done");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -144,12 +154,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	help = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	help = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(help, XmNactivateCallback, help_callback,
-						(XtPointer)"calconfig");
-	XtAddCallback(help, XmNhelpCallback,     help_callback,
-						(XtPointer)"calconfig");
+	XtAddCallback(help, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"calconfig");
+	XtAddCallback(help, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"calconfig");
 
 						/*------------- global ------*/
 	n = 0;
@@ -158,7 +168,7 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	w = XtCreateManagedWidget("Global options:",
+	w = XtCreateManagedWidget(_("Global options:"),
 			xmLabelWidgetClass, form, args, n);
 
 							/*-- frame --*/
@@ -182,29 +192,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.share_mainwin);	n++;
-	w = XtCreateManagedWidget("Use main window for all views",
+	w = XtCreateManagedWidget(_("Use main window for all views"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback,(XtPointer)14);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"global_flags");
-
-							/*-- auto-resize --*/
-#if 0
-	n = 0;
-	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
-	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
-	XtSetArg(args[n], XmNtopWidget,		w);			n++;
-	XtSetArg(args[n], XmNtopOffset,		4);			n++;
-	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
-	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	XtSetArg(args[n], XmNset,		config.resize_mainwin);	n++;
-	w = XtCreateManagedWidget("Auto-resize windows",
-			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback,(XtPointer)15);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"global_flags");
-#endif
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)14);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"global_flags");
 
 							/*-- sunday 1st --*/
 	n = 0;
@@ -216,11 +209,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.sunday_first);	n++;
-	w = XtCreateManagedWidget("Week begins with Sunday",
+	w = XtCreateManagedWidget(_("Week begins with Sunday"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"global_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"global_flags");
 
 							/*-- m/d/y --*/
 	n = 0;
@@ -232,11 +226,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.mmddyy);		n++;
-	w = XtCreateManagedWidget("Month/day/year date format",
+	w = XtCreateManagedWidget(_("Month/day/year date format"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback, (XtPointer)1);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"global_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)1);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"global_flags");
 
 							/*-- am/pm --*/
 	n = 0;
@@ -248,11 +243,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.ampm);		n++;
-	w = XtCreateManagedWidget("12-hour am/pm time format",
+	w = XtCreateManagedWidget(_("12-hour am/pm time format"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback, (XtPointer)2);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"global_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)2);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"global_flags");
 
 							/*-- autodelete --*/
 	n = 0;
@@ -264,11 +260,29 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.autodel);	n++;
-	w = XtCreateManagedWidget("Auto-delete past entries",
+	w = XtCreateManagedWidget(_("Auto-delete past entries"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback, (XtPointer)3);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"global_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)3);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"global_flags");
+
+							/*-- insecure script */
+	n = 0;
+	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
+	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNtopWidget,		w);			n++;
+	XtSetArg(args[n], XmNtopOffset,		4);			n++;
+	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
+	XtSetArg(args[n], XmNset,		config.insecure_script);n++;
+	w = XtCreateManagedWidget(_("Run netplan scripts (security risk!)"),
+			xmToggleButtonWidgetClass, form2, args, n);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)15);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"global_flags");
 
 							/*-- owner only --*/
 	n = 0;
@@ -281,11 +295,43 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.owner_only);	n++;
 	XtSetArg(args[n], XmNsensitive,		!all_files_served());	n++;
-	w = XtCreateManagedWidget("Only owner can write appt files",
+	w = w2 = XtCreateManagedWidget(_("Only owner can write appt files"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback,(XtPointer)11);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"global_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback,(XtPointer)11);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"global_flags");
+
+							/*-- default warn --*/
+	n = 0;
+	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNtopWidget,		w2);			n++;
+	XtSetArg(args[n], XmNtopOffset,		8);			n++;
+	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
+	w = XtCreateManagedWidget(_("Default warnings:"),
+			xmLabelWidgetClass, form2, args, n);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_defwarn");
+	n = 0;
+	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNtopWidget,		w2);			n++;
+	XtSetArg(args[n], XmNtopOffset,		4);			n++;
+	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNleftWidget,	w);			n++;
+	XtSetArg(args[n], XmNleftOffset,	16);			n++;
+	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNbottomOffset,	4);			n++;
+	XtSetArg(args[n], XmNwidth,		120);			n++;
+	XtSetArg(args[n], XmNrecomputeSize,	False);			n++;
+	XtSetArg(args[n], XmNpendingDelete,	True);			n++;
+	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
+	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
+	defwarn = XtCreateManagedWidget(" ", xmTextFieldWidgetClass,
+			form2, args, n);
+	XtAddCallback(defwarn, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_defwarn");
 
 						/*------------- month -------*/
 	n = 0;
@@ -295,7 +341,7 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	w = XtCreateManagedWidget("Month view options:",
+	w = XtCreateManagedWidget(_("Month view options:"),
 			xmLabelWidgetClass, form, args, n);
 
 							/*-- frame --*/
@@ -320,11 +366,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.julian);		n++;
-	w = XtCreateManagedWidget("Show Julian dates",
+	w = XtCreateManagedWidget(_("Show Julian dates"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback, (XtPointer)4);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"month_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)4);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"month_flags");
 
 							/*-- week num --*/
 	n = 0;
@@ -336,11 +383,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.weeknum);	n++;
-	w = XtCreateManagedWidget("Show week numbers",
+	w = XtCreateManagedWidget(_("Show week numbers"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback, (XtPointer)5);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"month_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)5);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"month_flags");
 
 							/*-- gps week --*/
 	n = 0;
@@ -352,11 +400,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.gpsweek);	n++;
-	w = XtCreateManagedWidget("Use GPS week numbers",
+	w = XtCreateManagedWidget(_("Use GPS week numbers"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback,(XtPointer)13);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"month_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback,(XtPointer)13);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"month_flags");
 
 							/*-- full week --*/
 	n = 0;
@@ -368,11 +417,29 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.fullweek);	n++;
-	w = XtCreateManagedWidget("First week is first full week",
+	w = XtCreateManagedWidget(_("First week is first full week"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback, (XtPointer)6);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"month_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)6);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"month_flags");
+
+							/*-- Thu week --*/
+	n = 0;
+	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
+	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNtopWidget,		w);			n++;
+	XtSetArg(args[n], XmNtopOffset,		4);			n++;
+	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
+	XtSetArg(args[n], XmNset,		config.thu_week);	n++;
+	w = XtCreateManagedWidget(_("First week is first week with Thursday"),
+			xmToggleButtonWidgetClass, form2, args, n);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback,(XtPointer)16);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"month_flags");
 
 							/*-- color code --*/
 	n = 0;
@@ -384,11 +451,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.colorcode_m);	n++;
-	w = XtCreateManagedWidget("Colored background for other files",
+	w = XtCreateManagedWidget(_("Colored background for other files"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback, (XtPointer)7);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"month_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)7);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"month_flags");
 
 							/*-- no past --*/
 	n = 0;
@@ -400,11 +468,12 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.nopast);		n++;
-	w = XtCreateManagedWidget("Don't show past entries in today's box",
+	w = XtCreateManagedWidget(_("Don't show past entries in today's box"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback, (XtPointer)8);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"month_flags");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)8);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"month_flags");
 
 
 						/*------------- week --------*/
@@ -415,7 +484,7 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	w = XtCreateManagedWidget("Week and Day view options:",
+	w = XtCreateManagedWidget(_("Week and Day view options:"),
 			xmLabelWidgetClass, form, args, n);
 
 							/*-- frame --*/
@@ -441,10 +510,10 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	w = XtCreateManagedWidget("Week view contains",
+	w = XtCreateManagedWidget(_("Week view contains"),
 			xmLabelWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"range_ndays");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_ndays");
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNtopOffset,		8);			n++;
@@ -458,8 +527,8 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	ndays = XtCreateManagedWidget(" ", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(ndays, XmNhelpCallback, help_callback,
-						(XtPointer)"range_ndays");
+	XtAddCallback(ndays, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_ndays");
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNtopOffset,		10);			n++;
@@ -467,10 +536,10 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftWidget,	ndays);			n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	XtCreateManagedWidget("days", xmLabelWidgetClass,
+	XtCreateManagedWidget(_("days"), xmLabelWidgetClass,
 			form2, args, n);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"range_ndays");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_ndays");
 
 							/*-- min --*/
 	n = 0;
@@ -480,10 +549,10 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	w = XtCreateManagedWidget("Begin view at",
+	w = XtCreateManagedWidget(_("Begin view at"),
 			xmLabelWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"range_min");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_min");
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		ndays);			n++;
@@ -497,8 +566,8 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	min = XtCreateManagedWidget(" ", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(min, XmNhelpCallback, help_callback,
-						(XtPointer)"range_min");
+	XtAddCallback(min, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_min");
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		ndays);			n++;
@@ -507,10 +576,10 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftWidget,	min);			n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	XtCreateManagedWidget("o'clock", xmLabelWidgetClass,
+	XtCreateManagedWidget(_("o'clock"), xmLabelWidgetClass,
 			form2, args, n);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"range_min");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_min");
 
 							/*-- max --*/
 	n = 0;
@@ -520,10 +589,10 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	w = XtCreateManagedWidget("End view at",
+	w = XtCreateManagedWidget(_("End view at"),
 			xmLabelWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"range_max");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_max");
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		min);			n++;
@@ -537,8 +606,8 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	max = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(max, XmNhelpCallback, help_callback,
-						(XtPointer)"range_max");
+	XtAddCallback(max, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_max");
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		min);			n++;
@@ -547,10 +616,10 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftWidget,	min);			n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	XtCreateManagedWidget("o'clock", xmLabelWidgetClass,
+	XtCreateManagedWidget(_("o'clock"), xmLabelWidgetClass,
 			form2, args, n);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"range_max");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_max");
 
 							/*-- show warnings --*/
 	n = 0;
@@ -562,12 +631,13 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.weekwarn);	n++;
-	w = XtCreateManagedWidget("Show advance-warning times",
+	w = XtCreateManagedWidget(_("Show advance-warning times"),
 			xmToggleButtonWidgetClass,
 			form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback,(XtPointer)9);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"range_warn");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback,(XtPointer)9);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_warn");
 
 							/*-- show filename --*/
 	n = 0;
@@ -579,12 +649,13 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.weekuser);	n++;
-	w = XtCreateManagedWidget("Show file names in bar labels",
+	w = XtCreateManagedWidget(_("Show file names in bar labels"),
 			xmToggleButtonWidgetClass,
 			form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback,(XtPointer)10);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"range_user");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback,(XtPointer)10);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_user");
 
 							/*-- notime bars --*/
 	n = 0;
@@ -596,26 +667,32 @@ void create_calconfig_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.week_bignotime);	n++;
-	w = XtCreateManagedWidget("Large bars for week entries without time",
+	w = XtCreateManagedWidget(_("Large bars for week entries without time"),
 			xmToggleButtonWidgetClass,
 			form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, flag_callback,(XtPointer)12);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"range_user");
-	XtPopup(shell, XtGrabNone);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)12);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_user");
+
+	XtRealizeWidget(shell);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
 	XtSetArg(args[0], XmNwidth,  &xs);
 	XtSetArg(args[1], XmNheight, &ys);
 	XtGetValues(form, args, 2);
 	XtSetArg(args[0], XmNwidth,  xs+8);
 	XtSetArg(args[1], XmNheight, ys+8);
 	XtSetValues(shell, args, 2);
+	XtPopup(shell, XtGrabNone);
 
-	print_text_button(ndays, "%d", config.week_ndays);
-	print_text_button(min,   "%d", config.week_minhour);
-	print_text_button(max,   "%d", config.week_maxhour);
+	a = config.early_time / 60;
+	b = config.late_time  / 60;
+	print_text_button(defwarn, a&&b ? "%d, %d" : a ? "%d" : "", a?a:b, b);
+	print_text_button(ndays,   "%d", config.week_ndays);
+	print_text_button(min,     "%d", config.week_minhour);
+	print_text_button(max,     "%d", config.week_maxhour);
 
 	have_shell = TRUE;
 }
@@ -627,10 +704,10 @@ void create_calconfig_popup()
  */
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_calconfig_popup();
 }
@@ -641,16 +718,16 @@ static BOOL *flagptr[] = {
 	&config.julian, &config.weeknum, &config.fullweek, &config.colorcode_m,
 	&config.nopast, &config.weekwarn,&config.weekuser, &config.owner_only,
 	&config.week_bignotime, &config.gpsweek, &config.share_mainwin,
-	&config.resize_mainwin
+	&config.insecure_script, &config.thu_week
 };
 
 /*ARGSUSED*/
-static void flag_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void flag_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
-	*flagptr[item] ^= TRUE;
+	*flagptr[item] = data->set;
 	if (flagptr[item] == &config.owner_only) {
 		read_mainlist();
 		if (!config.owner_only)
