@@ -21,6 +21,8 @@ typedef void		*XPoint;
 typedef unsigned long	XtInputId;
 typedef unsigned short	Dimension;
 typedef int		Region;
+typedef void		*XEvent;		/* open Motif */
+typedef int		Boolean;		/* open Motif */
 
 #include <stdio.h>
 #include <stdlib.h>
