@@ -24,7 +24,7 @@ extern int		curr_year;	/* year being displayed, since 1900 */
 time_t			curr_day;	/* day being displayed, time in sec */
 struct week		day;		/* info on day view */
 
-static BOOL add_day_entry();
+static BOOL add_day_entry(int, time_t, BOOL, struct entry *, int);
 
 
 /*
@@ -34,9 +34,9 @@ static BOOL add_day_entry();
  * prev is vertical because the time-of-day axis is vertical in day views.
  */
 
-void build_day(omit_priv, omit_all)
-	BOOL		omit_priv;	/* ignore private (padlocked) entries*/
-	BOOL		omit_all;	/* ignore all ent (not very useful) */
+void build_day(
+	BOOL		omit_priv,	/* ignore private (padlocked) entries*/
+	BOOL		omit_all)	/* ignore all ent (not very useful) */
 {
 	struct config	*c = &config;
 	time_t		date;		/* midnight of calculated day */
@@ -62,7 +62,7 @@ void build_day(omit_priv, omit_all)
 	curr_day = date = curr_day - curr_day % 86400;
 	if (!(day.tree   = malloc(NDAYS * sizeof(struct weeknode *))) ||
 	    !(day.nlines = malloc(NDAYS * sizeof(int))))
-		fatal("no memory for day view");
+		fatal(_("no memory for day view"));
 	memset((void *)day.tree,   0, NDAYS * sizeof(struct weeknode *));
 	memset((void *)day.nlines, 0, NDAYS * sizeof(int));
 
@@ -136,12 +136,12 @@ void build_day(omit_priv, omit_all)
 			 : node->trigger + ep->length;			   \
 }
 
-static BOOL add_day_entry(wday, time, warn, new, u)
-	int		wday;			/* day counter, 0..NDAYS-1 */
-	time_t		time;			/* appropriate trigger time */
-	BOOL		warn;			/* it's a n-days-ahead warng */
-	struct entry	*new;			/* entry to insert */
-	int		u;			/* owner user, 0=own */
+static BOOL add_day_entry(
+	int		wday,			/* day counter, 0..NDAYS-1 */
+	time_t		time,			/* appropriate trigger time */
+	BOOL		warn,			/* it's a n-days-ahead warng */
+	struct entry	*new,			/* entry to insert */
+	int		u)			/* owner user, 0=own */
 {
 	struct weeknode	*node;			/* new day struct */
 	struct weeknode	*vert;			/* for finding free line */
@@ -214,7 +214,7 @@ static BOOL add_day_entry(wday, time, warn, new, u)
  * destroy the day trees for all days.
  */
 
-void destroy_day()
+void destroy_day(void)
 {
 	int		wday;			/* day counter */
 	struct weeknode	*vert, *nextvert;	/* line pointer */
