@@ -1004,7 +1004,7 @@ static void list_delete(
 	delete_entry(mainlist, lw->sublist->entry[edit.y-1] - mainlist->entry);
 
 	rebuild_repeat_chain(mainlist);
-	draw_list(edit.menu);
+	/* draw_list(edit.menu); 1.8.4 */
 	update_all_listmenus();
 	redraw_all_views();
 }
