@@ -85,7 +85,6 @@ BOOL copyfile(
 
 void write_mainlist(void)
 {
-	struct stat	sbuf;		/* check for directories */
 	int		u;		/* user counter */
 	char		path[1024];	/* user file name to write */
 
@@ -104,13 +103,9 @@ void write_mainlist(void)
 									u);
 			continue;
 		}
-		if (!stat(resolve_tilde(user[u].path), &sbuf) &&
-							IS_DIR(sbuf.st_mode))
-			strcpy(path, DB_PUB_PATH);
-		else
-			strcpy(path, user[u].path);
-		user[u].readonly = !access(resolve_tilde(path), F_OK) &&
-				  !!access(resolve_tilde(path), W_OK);
+		strcpy(path, find_pub_path(user[u].path));
+		user[u].readonly = !access(path, F_OK) &&
+				  !!access(path, W_OK);
 		user[u].time     = get_time();
 		if (writefile(mainlist, path, u, WR_PUBLIC))
 			user[u].modified = 0;
@@ -161,6 +156,8 @@ static BOOL writefile(
 	int			i;		/* entry counter */
 	BOOL			write_error = FALSE;
 
+	if (user[u].readonly)
+		return(TRUE);
 	list->locked = TRUE;
 	path = resolve_tilde(path);
 	if (user[u].grok) {
@@ -212,8 +209,8 @@ static BOOL writefile(
 			write_error = TRUE;
 		}
 		errno = 0;
-		if (rfp && !write_error)
-			for (;;) {
+		if (rfp) {
+			while (!write_error) {
 				if (!fgets(line, 1024, rfp))
 					break;
 				if (*line >= '0' && *line <= '9')
@@ -221,7 +218,8 @@ static BOOL writefile(
 				fputs(line, fp);
 				write_error |= errno && errno != ENOTTY;
 			}
-		fclose(rfp);
+			fclose(rfp);
+		}
 	}
 							/* write temp db */
 	if (what & WR_CONFIG) {
@@ -447,40 +445,24 @@ int write_one_entry(
 			write_error |= (*callback)(line);
 		}
 
-	if (ep->note)
-		for (p=ep->note; *p; ) {
-			line[0] = 'N';
-			line[1] = '\t';
-			for (q=line+2; *p && *p != '\n'; )
-				*q++ = *p++;
-			*q++ = '\n';
-			*q = 0;
-			write_error |= (*callback)(line);
-			if (*p) p++;
-		}
-
-	if (ep->message)
-		for (p=ep->message; *p; ) {
-			line[0] = 'M';
-			line[1] = '\t';
-			for (q=line+2; *p && *p != '\n'; )
-				*q++ = *p++;
-			*q++ = '\n';
-			*q = 0;
-			write_error |= (*callback)(line);
-			if (*p) p++;
-		}
-
-	if (ep->script)
-		for (p=ep->script; *p; ) {
-			line[0] = 'S';
-			line[1] = '\t';
-			for (q=line+2; *p && *p != '\n'; )
-				*q++ = *p++;
-			*q++ = '\n';
-			*q = 0;
-			write_error |= (*callback)(line);
-			if (*p) p++;
+	for (j=0; j < 4; j++) {
+		switch(j) {
+		  case 0: p=ep->note;	 break;
+		  case 1: p=ep->message; break;
+		  case 2: p=ep->script;	 break;
+		  case 3: p=ep->java;	 break;
 		}
+		if (p)
+			while (*p) {
+				line[0] = "NMSJ"[j];
+				line[1] = '\t';
+				for (q=line+2; *p && *p != '\n'; )
+					*q++ = *p++;
+				*q++ = '\n';
+				*q = 0;
+				write_error |= (*callback)(line);
+				if (*p) p++;
+			}
+	}
 	return(write_error);
 }
