@@ -8,6 +8,7 @@
 #include <X11/Xos.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <time.h>
 #include <sys/stat.h>
 #include <assert.h>
 #include <signal.h>
@@ -20,11 +21,15 @@
 #include <Xm/Xm.h>
 #include "config.h"
 
+#ifdef GROK
+#include "proto.h"
+#endif
+#ifdef PLANGROK
+#include "cal.h"
+#endif
 #if defined(GROK) || defined(PLANGROK)
-
 #include "grok.h"
 #include "form.h"
-#include "proto.h"
 
 #define R_SEP	'\n'			/* row (card) separator */
 #define ESC	'\\'			/* treat next char literally */
@@ -100,7 +105,7 @@ static BOOL writefile(
 			"Database has no name, cannot save to disk");
 		return(FALSE);
 	}
-	path = resolve_tilde(path, 0);
+	path = resolve_tilde(path);
 	if (form->proc) {
 		char cmd[1024];
 		sprintf(cmd, "%s -w %s", path, form->name);
@@ -284,7 +289,7 @@ static BOOL read_dir_or_file(
 
 	if (stat(path, &statbuf))
 		return(FALSE);
-	if (!(statbuf.st_mode & S_IFDIR))
+	if (!IS_DIR(statbuf.st_mode))
 		return(read_file(dbase, form, path, statbuf.st_mtime));
 	if (!(dir = opendir(path)))
 		return(FALSE);
@@ -332,12 +337,12 @@ static BOOL read_file(
 	signal(SIGPIPE, broken_pipe_handler);
 	if (form->proc) {
 		char cmd[1024];
-		path = resolve_tilde(path, "db");
+		path = resolve_tilde(path);
 		sprintf(cmd, "%s -r %s", path, form->name);
 		if (!(fp = popen(cmd, "r")))
 			return(FALSE);
 	} else {
-		path = resolve_tilde(path, "db");
+		path = resolve_tilde(path);
 		if (!(fp = fopen(path, "r")))
 			return(FALSE);
 	}
@@ -382,19 +387,19 @@ static BOOL read_file(
 			if (i >= 0 && item->type == IT_TIME)	/* .. -> int */
 				switch(item->timefmt) {
 				  case T_DATE:
-					sprintf(buf, "%d",
-						parse_datestring(buf));
+					sprintf(buf, "%d", (int)
+						parse_datestring(buf, 0));
 					break;
 				  case T_TIME:
-					sprintf(buf, "%d",
+					sprintf(buf, "%d", (int)
 						parse_timestring(buf, FALSE));
 					break;
 				  case T_DATETIME:
-					sprintf(buf, "%d",
+					sprintf(buf, "%d", (int)
 						parse_datetimestring(buf));
 					break;
 				  case T_DURATION:
-					sprintf(buf, "%d",
+					sprintf(buf, "%d", (int)
 						parse_timestring(buf, TRUE));
 				}
 								/* store str */
