@@ -458,6 +458,7 @@ static void draw_day_notes(
 	int			ys;		/* height of a text line */
 	char			buf[100];	/* string buffer (time/note) */
 	int			jul;		/* julian date of daybox */
+	int			nlines = 0;	/* # printed, <lines_per_day */
 	struct holiday		*hp;		/* holiday info for this day */
 	char			*errmsg;	/* parser error */
 	Window			window;
@@ -559,8 +560,10 @@ static void draw_day_notes(
 		XDrawString(display, window, gc, x+2, y, buf, strlen(buf));
 #endif
 		y += descent/2;
-		if (drawn_entry)
+		if (drawn_entry) {
+			nlines++;
 			drawn_entry++;
+		}
 	}
 							/* entry loop */
 	found = lookup_entry(&lookup, mainlist, daytime, TRUE, FALSE, 'm', -1);
@@ -635,7 +638,7 @@ static void draw_day_notes(
 		XDrawString(display, window, gc, x+2+xo, y, buf, strlen(buf));
 #endif
 		y += font[FONT_NOTE]->max_bounds.descent/2;
-		if (drawn_entry)
+		if (drawn_entry && nlines++ < lines_per_day)
 			*drawn_entry++ = ep;
 	}
 	set_color(COL_STD);
