@@ -10,10 +10,8 @@
  *					view, and everything in it.
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <varargs.h>
 #include <Xm/Xm.h>
@@ -31,9 +29,11 @@
 #include <Xm/DrawingA.h>
 #include "cal.h"
 
-extern MOUSE locate_in_month_calendar();
-static void resize_mainwindow(),
-	    month_down(), month_up(), year_down(), year_up();
+static void resize_mainwindow	(Widget, Dimension, Dimension);
+static void month_down		(Widget, int, XmToggleButtonCallbackStruct *);
+static void month_up		(Widget, int, XmToggleButtonCallbackStruct *);
+static void year_down		(Widget, int, XmToggleButtonCallbackStruct *);
+static void year_up		(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern GC		gc;		/* everybody uses this context */
@@ -54,7 +54,7 @@ static BOOL		have_view;	/* <all> is a valid widget */
  * the time widget gets the new time printed into it every minute otherwise.
  */
 
-void destroy_month_view()
+void destroy_month_view(void)
 {
 	if (have_view) {
 		XTDESTROYWIDGET(all);
@@ -76,18 +76,19 @@ void destroy_month_view()
  * go into the mainwindow. Thus, we only have create/destroy view routines.
  */
 
-void create_month_view(parent)
-	Widget			parent;
+void create_month_view(
+	Widget		parent)
 {
-	Arg			args[15];
-	int			n;
-	Widget			arrow, scroll;
-	int			sm = config.smallmonth;
-	Dimension		draw_xs, draw_ys;
-	Dimension		inset_xs, inset_ys;
+	Arg		args[15];
+	int		n;
+	Widget		arrow, scroll;
+	int		sm = config.smallmonth;
+	Dimension	draw_xs, draw_ys;
+	Dimension	inset_xs, inset_ys;
 
 	all = XtCreateWidget("all", xmFormWidgetClass, parent, NULL, 0);
-	XtAddCallback(all, XmNhelpCallback, help_callback, (XtPointer)"cal");
+	XtAddCallback(all, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cal");
 
 	draw_xs = 2 * config.calbox_marg [sm] +
 		  1 * config.calbox_arrow[sm] +
@@ -124,9 +125,10 @@ void create_month_view(parent)
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	arrow = XtCreateManagedWidget("nexty", xmArrowButtonWidgetClass,
 			all, args, n);
-	XtAddCallback(arrow, XmNactivateCallback, year_up, (XtPointer)0);
-	XtAddCallback(arrow, XmNhelpCallback, help_callback,
-							(XtPointer)"cal_year");
+	XtAddCallback(arrow, XmNactivateCallback, (XtCallbackProc)
+			year_up, (XtPointer)0);
+	XtAddCallback(arrow, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cal_year");
 
 	n = 0;
 	XtSetArg(args[n], XmNarrowDirection,	XmARROW_LEFT);		n++;
@@ -140,9 +142,10 @@ void create_month_view(parent)
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	arrow = XtCreateManagedWidget("prevy", xmArrowButtonWidgetClass,
 			all, args, n);
-	XtAddCallback(arrow, XmNactivateCallback, year_down, (XtPointer)0);
-	XtAddCallback(arrow, XmNhelpCallback, help_callback,
-							(XtPointer)"cal_year");
+	XtAddCallback(arrow, XmNactivateCallback, (XtCallbackProc)
+			year_down, (XtPointer)0);
+	XtAddCallback(arrow, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cal_year");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -152,8 +155,8 @@ void create_month_view(parent)
 	XtSetArg(args[n], XmNrightOffset,	4);			n++;
 	mainmenu.year = XtCreateManagedWidget("year", xmLabelWidgetClass,
 			all, args, n);
-	XtAddCallback(mainmenu.year, XmNhelpCallback, help_callback,
-						(XtPointer)"cal_year");
+	XtAddCallback(mainmenu.year, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cal_year");
 
 	n = 0;							/* month */
 	XtSetArg(args[n], XmNarrowDirection,	XmARROW_RIGHT);		n++;
@@ -167,9 +170,10 @@ void create_month_view(parent)
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	arrow = XtCreateManagedWidget("nextm", xmArrowButtonWidgetClass,
 			all, args, n);
-	XtAddCallback(arrow, XmNactivateCallback, month_up, (XtPointer)0);
-	XtAddCallback(arrow, XmNhelpCallback, help_callback,
-						(XtPointer)"cal_month");
+	XtAddCallback(arrow, XmNactivateCallback, (XtCallbackProc)
+			month_up, (XtPointer)0);
+	XtAddCallback(arrow, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cal_month");
 
 	n = 0;
 	XtSetArg(args[n], XmNarrowDirection,	XmARROW_LEFT);		n++;
@@ -183,13 +187,14 @@ void create_month_view(parent)
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	arrow = XtCreateManagedWidget("prevm", xmArrowButtonWidgetClass,
 			all, args, n);
-	XtAddCallback(arrow, XmNactivateCallback, month_down, (XtPointer)0);
-	XtAddCallback(arrow, XmNhelpCallback, help_callback,
-						(XtPointer)"cal_month");
+	XtAddCallback(arrow, XmNactivateCallback, (XtCallbackProc)
+			month_down, (XtPointer)0);
+	XtAddCallback(arrow, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cal_month");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
-#if LESSTIF_VERSION != 0
+#if LesstifVersion >= 88
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	mainmenu.time);		n++;
 #endif
@@ -200,8 +205,8 @@ void create_month_view(parent)
 	XtSetArg(args[n], XmNalignment,		XmALIGNMENT_END);	n++;
 	mainmenu.month = XtCreateManagedWidget("month", xmLabelWidgetClass,
 			all, args, n);
-	XtAddCallback(mainmenu.month, XmNhelpCallback, help_callback,
-						(XtPointer)"cal_month");
+	XtAddCallback(mainmenu.month, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cal_month");
 
 	n = 0;							/* calendar */
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -224,8 +229,8 @@ void create_month_view(parent)
 	XtSetArg(args[n], XmNheight,		draw_ys);		n++;
 	mainmenu.cal = XtCreateWidget("cal", xmDrawingAreaWidgetClass,
 			scroll, args, n);
-	XtAddCallback(mainmenu.cal, XmNhelpCallback,   help_callback,
-							(XtPointer)"cal");
+	XtAddCallback(mainmenu.cal, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cal");
 	drag_init('m', mainmenu.cal, 0, draw_calendar,
 					locate_in_month_calendar);
 	XtManageChild(mainmenu.cal);
@@ -245,9 +250,10 @@ void create_month_view(parent)
  * of the calendar to the window based on the original size.
  */
 
-static void resize_mainwindow(win, xs, ys)
-	Widget		 win;		/* mainwindow */
-	Dimension	 xs, ys;	/* space needed for calendar */
+static void resize_mainwindow(
+	Widget		 win,		/* mainwindow */
+	Dimension	 xs,		/* space needed for calendar */
+	Dimension	 ys)
 {
 	Widget		 window;
 	Dimension	 win_xs,  win_ys;
@@ -274,10 +280,10 @@ static void resize_mainwindow(win, xs, ys)
  */
 
 /*ARGSUSED*/
-static void month_down(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void month_down(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (curr_month <= 0) {
 		if (curr_year <= 0)
@@ -293,10 +299,10 @@ static void month_down(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void month_up(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void month_up(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (curr_month >= 11) {
 		if (curr_year >= 2037)
@@ -312,10 +318,10 @@ static void month_up(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void year_down(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void year_down(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (curr_year <= 70)
 		return;
@@ -326,10 +332,10 @@ static void year_down(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void year_up(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void year_up(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (curr_year >= 137)
 		return;
