@@ -44,6 +44,7 @@ static Boolean suppress_daemon_warning = False;
 extern char		*progname;	/* argv[0] */
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		mainwindow;	/* popup menus hang off main window */
+extern XtAppContext	app;		/* application handle */
 extern BOOL		interactive;	/* interactive or fast appt entry? */
 extern BOOL		startup_lock();
 
@@ -263,6 +264,8 @@ may cause loss of new appointment entries, and\n\
 command-line entry of appointments will not work.";
 
 static void kill_callback(Widget, XtPointer, XtPointer);
+static void cont_callback(Widget, XtPointer, XtPointer);
+static BOOL cont;
 
 void create_multiple_popup(
 	BOOL		nolock)		/* tried to kill competitor */
@@ -273,6 +276,7 @@ void create_multiple_popup(
 	Arg		args[10];
 	int		n;
 
+	cont = FALSE;
 	sprintf(msg, _(multiple_message), progname,
 		nolock ? _("The other program could not be killed.\n") : "");
 	s1 = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
@@ -290,14 +294,24 @@ void create_multiple_popup(
 	XmStringFree(s3);
 	XtAddCallback(dialog, XmNokCallback, (XtCallbackProc)
 			kill_callback, (XtPointer)NULL);
+	XtAddCallback(dialog, XmNcancelCallback, (XtCallbackProc)
+			cont_callback, (XtPointer)NULL);
 	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON));
 	(void)XmInternAtom(display, "WM_DELETE_WINDOW", False);
 	XtManageChild(dialog);
+	fprintf(stderr, "waiting...\n"); fflush(stdout);
+	while (!cont) {
+		XEvent event;
+		XtAppNextEvent(app, &event);
+		XtDispatchEvent(&event);
+	}
+	fprintf(stderr, "continue...\n"); fflush(stdout);
 }
 
 
 /*
- * The user pressed Kill. Try to acquire a lock.
+ * The user pressed Kill. Try to acquire a lock, then let
+ * create_multiple_popup continue so that the main plan window can come up.
  */
 
 /*ARGSUSED*/
@@ -308,6 +322,22 @@ static void kill_callback(
 {
 	if (!startup_lock(resolve_tilde(PLANLOCK), TRUE))
 		create_multiple_popup(TRUE);
+	cont = TRUE;
+}
+
+
+/*
+ * The user pressed Continue. Let create_multiple_popup continue so that the
+ * main plan window can come up.
+ */
+
+/*ARGSUSED*/
+static void cont_callback(
+	Widget		dialog,
+	XtPointer	a,
+	XtPointer	b)
+{
+	cont = TRUE;
 }
 
 
