@@ -160,6 +160,8 @@ extern void delete_entry_by_id(
 
 /*---------------------------------------- file_r.c ------------*/
 
+extern char *find_pub_path(		/* return the calendar path */
+        char            *path);		/* resolve ~ and make absolute */
 extern BOOL read_mainlist(void);	/* read all files into mainlist */
 extern void parse_file_line(		/* parse one line from appt file */
 	struct plist	**list,		/* list to add to */
