@@ -27,6 +27,7 @@ extern GC		jgc, gc;	/* graphic context, Japanese and std */
 extern GC		chk_gc;		/* checkered gc for light background */
 extern XFontStruct	*font[NFONTS];	/* fonts: FONT_* */
 extern struct config	config;		/* global configuration data */
+extern XColor		xcolor[NCOLS];	/* useful for PostScript color */
 
 static FILE		*fp;		/* PostScript file, or 0 if window */
 static BOOL		ps_landscape;	/* if PostScript, rotate 90 degrees */
@@ -43,9 +44,9 @@ static Region		region;		/* if fp==0, X clip region */
  * overview. Return FALSE if drawing is not possible.
  */
 
-BOOL g_init_window(week, newregion)
-	struct week	*week;		/* either &week or &yov */
-	Region		newregion;	/* draw only here */
+BOOL g_init_window(
+	struct week	*week,		/* either &week or &yov */
+	Region		newregion)	/* draw only here */
 {
 	Arg		args[2];
 
@@ -86,10 +87,10 @@ void g_exit_window(void)
  * ISO code suggested by Axel Stegner <stegner@fb3-s7.math.tu-berlin.de>.
  */
 
-void g_init_ps(week, newfp, landscape)
-	struct week	*week;		/* either &week or &yov */
-	FILE		*newfp;
-	BOOL		landscape;
+void g_init_ps(
+	struct week	*week,		/* either &week or &yov */
+	FILE		*newfp,
+	BOOL		landscape)
 {
 #ifdef JAPAN
 	fprintf(fp = newfp,
@@ -153,10 +154,18 @@ void g_exit_ps(void)
  * highlighted.
  */
 
-void g_setcolor(color)
-	int color;
+void g_setcolor(
+	int	color)
 {
-	if (fp) {
+	if (!fp)					/* to window */
+		set_color(color);
+
+	else if (config.pr_color)			/* color PostScript */
+		fprintf(fp, "%g %g %g setrgbcolor ",
+			xcolor[color].red   / 65536.,
+			xcolor[color].green / 65536.,
+			xcolor[color].blue  / 65536.);
+	else {						/* b/w PostScript */
 		double col;
 		if (color >= COL_WUSER_1 && color <= COL_WUSER_7)
 			col = (color - COL_WUSER_1) / 7.0 * 0.15 + 0.8;
@@ -179,17 +188,16 @@ void g_setcolor(color)
 		  default:		col = 0;	break;
 		}
 		fprintf(fp, "%g setgray ", col);
-	} else
-		set_color(color);
+	}
 }
 
-void g_setfont(fonti)
-	int fonti;
+void g_setfont(
+	int	fonti)
 {
 	if (fp) {
 		fprintf(fp, "DefNormFont %d scalefont setfont\n",
-			ps_landscape ? fonti == FONT_WTITLE ? 22 : 9
-				     : fonti == FONT_WTITLE ? 15 : 7);
+			ps_landscape ? fonti == FONT_WTITLE ? 20 : 8
+				     : fonti == FONT_WTITLE ? 14 : 6);
 	}
 #ifdef JAPAN
 	else if (fonti == FONT_JNOTE)
@@ -199,8 +207,12 @@ void g_setfont(fonti)
 		XSetFont(display, gc, font[fonti]->fid);
 }
 
-void g_fillrect(x, y, xs, ys)
-	int x, y, xs, ys;
+
+void g_fillrect(
+	int	x,
+	int	y,
+	int	xs,
+	int	ys)
 {
 	if (fp) {
 		fprintf(fp,
@@ -214,13 +226,16 @@ void g_fillrect(x, y, xs, ys)
 		XFillRectangle(display, window, gc, x, y, xs, ys);
 }
 
-void g_drawtext(x, y, text, len)
-	char	*text;
-	int	x, y, len;
+
+void g_drawtext(
+	int	x,
+	int	y,
+	char	*text,
+	int	len)
 {
 	if (fp) {
 		fprintf(fp, "%g %g moveto (", XSCALE(x), YSCALE(y));
-		while (*text) {
+		while (*text && len--) {
 			if (*text == '(' || *text == ')')
 				fputc('\\', fp);
 			fputc(*text++, fp);
@@ -230,14 +245,19 @@ void g_drawtext(x, y, text, len)
 		XDrawString(display, window, gc, x, y, text, len);
 }
 
+
 #ifdef JAPAN
-void g_drawtext16(x, y, text, len)
-	char	*text;
+void g_drawtext16(
+        int             x,
+        int             y,
+        char            *text,
+        int             len)
 {
 	if (fp) {
-		fprintf(fp, "gsave DefJapaneseFont %d scalefont setfont\n%g %g moveto <",
-			ps_landscape ? 9 : 7, XSCALE(x), YSCALE(y));
-		while (*text != '\0')
+		fprintf(fp, "gsave DefJapaneseFont %d scalefont setfont\n"
+				"%g %g moveto <",
+				ps_landscape ? 9 : 7, XSCALE(x), YSCALE(y));
+		while (*text && len--)
 			fprintf(fp, "%02X", *text++);
 		fprintf(fp, "> show grestore\n");
 	} else
@@ -245,10 +265,11 @@ void g_drawtext16(x, y, text, len)
 }
 #endif
 
-void g_drawpoly(point, num, checker)
-	XPoint	*point;
-	int	num;
-	BOOL	checker;
+
+void g_drawpoly(
+	XPoint	*point,
+	int	num,
+	BOOL	checker)
 {
 	if (fp) {
 		int n;
@@ -267,9 +288,10 @@ void g_drawpoly(point, num, checker)
 	}
 }
 
-void g_drawlines(point, num)
-	XPoint	*point;
-	int	num;
+
+void g_drawlines(
+	XPoint	*point,
+	int	num)
 {
 	if (fp) {
 		int n;
