@@ -182,14 +182,13 @@ static BOOL accept_new_list(void)
 	for (u=nusers-1; u >= 0; u--)
 		if (!user[u].prev_fromserver && user[u].fromserver)
 			break;
-	if (u < 0)
-		return(TRUE);
-	if (msg = attach_to_network()) {
+	if (u >= 0) {
+	    if (msg = attach_to_network()) {
 		create_error_popup(shell, 0, msg);
 		free(msg);
 		return(FALSE);
-	}
-	for (up=user, u=0; u < nusers; u++, up++) {
+	    }
+	    for (up=user, u=0; u < nusers; u++, up++) {
 		if (!up->fromserver || up->prev_fromserver)
 			continue;
 		nremote = open_and_count_rows_on_server(u);
@@ -243,6 +242,7 @@ static BOOL accept_new_list(void)
 				  "server and ignoring\nfile %s."),
 				up->name, nlocal, up->path,
 				nremote, up->server, up->path);
+	    }
 	}
 	mainlist->modified = TRUE;
 	write_mainlist();
@@ -771,9 +771,10 @@ static void got_user_text(
 	}
 							/* default path? */
 	if (u->name && *u->name && !u->path) {
-		if (pw = getpwnam(u->name))
-			u->path = mystrdup(pw->pw_dir);
-		else {
+		if (pw = getpwnam(u->name)) {
+			sprintf(buf, "~%s", u->name);
+			u->path = mystrdup(buf);
+		} else {
 			sprintf(buf, "%s/%s", LIB, u->name);
 			print_button(info, _("no user \"%s\""), u->name);
 			u->path = mystrdup(buf);
