@@ -17,21 +17,16 @@
 #include "cal.h"
 
 #define DBLTIME		1000		/* doubleclick time [ms] */
-
 #define SLOPE		1/4		/* slope of arrow head / barheight */
 #define MINLEN		8		/* no bar is shorter than MINLEN */
-
 #define TOD(t)		((t)%86400)
 #define BOUND(t,a,b)	((t)<(a) ? (a) : (t)>(b) ? (b) : (t));
 #define XPOS(t)		(((t) - c->week_minhour*3600) * c->week_hourwidth/3600)
 
-static void gen_week();
-static void draw_week_day_foreground(), draw_week_day_background(), draw_bar();
-
-#ifdef JAPAN
-int truncate_strpack();
-void g_draw_strpack();
-#endif
+static void gen_week			(void);
+static void draw_week_day_background	(int);
+static void draw_week_day_foreground	(int);
+static void draw_bar			(struct weeknode *, int, int, int);
 
 extern Display		*display;	/* everybody uses the same server */
 extern XFontStruct	*font[NFONTS];	/* fonts: FONT_* */
@@ -44,9 +39,6 @@ extern struct plist	*mainlist;	/* list of all schedule entries */
 extern struct holiday	holiday[366];	/* info for each day, separate for */
 extern struct holiday	sm_holiday[366];/* full-line texts under, and small */
 
-extern char *weekday_name[];
-extern char *monthname[];
-
 
 /*
  * for a given position on the canvas, identify the entry there and return
@@ -64,19 +56,21 @@ extern char *monthname[];
  *   M_RIGHT	entry	time	trigg	pos/sz	near right edge, move length
  */
 
-MOUSE locate_in_week_calendar(epp, warn, time, trigger, xp,yp,xsp,ysp, xc,yc)
-	struct entry		**epp;		/* returned entry or 0 */
-	BOOL			*warn;		/* is *epp an n-days-ahead w?*/
-	time_t			*time;		/* if *epp=0, clicked where */
-	time_t			*trigger;	/* if *epp=0, entry trigger */
-	int			*xp,  *yp;	/* if M_INSIDE, rubber box */
-	int			*xsp, *ysp;	/* position and size */
-	int			xc, yc;		/* pixel pos clicked */
+MOUSE locate_in_week_calendar(
+	struct entry		**epp,		/* returned entry or 0 */
+	BOOL			*warn,		/* is *epp an n-days-ahead w?*/
+	time_t			*time,		/* if *epp=0, clicked where */
+	time_t			*trigger,	/* if *epp=0, entry trigger */
+	int			*xp,		/* if M_INSIDE, rubber box */
+	int			*yp,
+	int			*xsp,		/* position and size */
+	int			*ysp,
+	int			xc,		/* pixel pos clicked */
+	int			yc)
 {
 	register struct config	*c = &config;
 	struct weeknode		*vert, *horz;	/* yov node scan pointers */
 	register struct entry	*ep;		/* entry to test */
-	int			daysz;		/* horz pixels per day */
 	int			d;		/* day strip counter */
 	int			yd;		/* y start coord of day box */
 	int			x, y;		/* upper left of day bk box */
@@ -160,8 +154,10 @@ MOUSE locate_in_week_calendar(epp, warn, time, trigger, xp,yp,xsp,ysp, xc,yc)
  * changed on the specified day).
  */
 
-void draw_week_day(day, month, year)
-	int		day, month, year;
+void draw_week_day(
+	int		day,
+	int		month,
+	int		year)
 {
 	struct tm	tm;
 	time_t		date;
@@ -187,8 +183,8 @@ void draw_week_day(day, month, year)
  * if null).
  */
 
-void draw_week_calendar(region)
-	Region	region;
+void draw_week_calendar(
+	Region	region)
 {
 	if (!g_init_window(&week, region))
 		return;
@@ -203,9 +199,9 @@ void draw_week_calendar(region)
  * print PostScript week calendar to file fp.
  */
 
-void print_week_calendar(fp, landscape)
-	FILE	*fp;
-	BOOL	landscape;
+void print_week_calendar(
+	FILE	*fp,
+	BOOL	landscape)
 {
 	time_t time = get_time();
 	struct tm *tm = time_to_tm(time);
@@ -224,7 +220,7 @@ void print_week_calendar(fp, landscape)
  * draw the week, using low-level routines
  */
 
-static void gen_week()
+static void gen_week(void)
 {
 	register struct config	*c = &config;
 	char			buf[40], *p;
@@ -279,9 +275,12 @@ static void gen_week()
  * printed after the thin hour lines are drawn by the caller, by calling the
  * following routine.
  */
+#ifdef JAPAN
+void g_draw_strpack();
+#endif
 
-static void draw_week_day_background(wday)
-	int			wday;		/* day of the week, < NDAYS */
+static void draw_week_day_background(
+	int			wday)		/* day of the week, < NDAYS */
 {
 	register struct config	*c = &config;
 	time_t			today;		/* today's date */
@@ -378,8 +377,8 @@ static void draw_week_day_background(wday)
  * drawn by the caller.
  */
 
-static void draw_week_day_foreground(wday)
-	int			wday;		/* day of the week, < NDAYS */
+static void draw_week_day_foreground(
+	int			wday)		/* day of the week, < NDAYS */
 {
 	register struct config	*c = &config;
 	struct weeknode		*vert, *horz;	/* week node scan pointers */
@@ -406,10 +405,11 @@ static void draw_week_day_foreground(wday)
  * draw one entry bar.
  */
 
-static void draw_bar(node, color, x, y)
-	struct weeknode		*node;		/* entry node to print */
-	int			color;		/* color, 0..7 */
-	int			x, y;		/* top left pos in canvas */
+static void draw_bar(
+	struct weeknode		*node,		/* entry node to print */
+	int			color,		/* color, 0..7 */
+	int			x,		/* top left pos in canvas */
+	int			y)
 {
 	register struct entry	*ep = node->entry;
 	register struct config	*c = &config;
@@ -533,13 +533,13 @@ static void draw_bar(node, color, x, y)
 }
 
 #ifdef JAPAN
-int truncate_strpack(partialstr, maxpix, ascfont)
-	strpack			*partialstr;
-	int			maxpix,		/* Maximum width in pixels. */
-				ascfont;	/* ascii font to draw */
+int truncate_strpack(
+	strpack		*partialstr,
+	int		maxpix,		/* Maximum width in pixels. */
+	int		ascfont)	/* ascii font to draw */
 {
-	int			plen = 0;
-	strpack			*upperpartstr;
+	int		plen = 0;
+	strpack		*upperpartstr;
 
 	for (upperpartstr = partialstr + MAXPARTIALSTRING;
 	     partialstr < upperpartstr && partialstr->strptr != NULL;
@@ -571,9 +571,10 @@ int truncate_strpack(partialstr, maxpix, ascfont)
 	return plen;
 }
 
-void g_draw_strpack(x, y, partialstr)
-	strpack			*partialstr;
-	int			x, y;
+void g_draw_strpack(
+	strpack			*partialstr,
+	int			x,
+	int			y)
 {
 	strpack			*upperpartstr;
 
