@@ -6,10 +6,8 @@
  *					window.
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <varargs.h>
 #include <Xm/Xm.h>
@@ -28,9 +26,11 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-extern MOUSE locate_in_week_calendar();
-static void done_callback(), edit_callback(), sync_callback();
-static void prev_callback(), next_callback();
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void edit_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void sync_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void prev_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void next_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern struct config	config;		/* global configuration data */
@@ -47,7 +47,7 @@ static Widget		shell;		/* week window, 0 if none */
  * destroy the week menu. Remove it from the screen, and destroy its widgets.
  */
 
-void destroy_week_menu()
+void destroy_week_menu(void)
 {
 	if (shell) {
 		if (!parent_form)
@@ -65,23 +65,24 @@ void destroy_week_menu()
  * create the week menu for the week beginning on curr_week.
  */
 
-void create_week_menu(parent)
-	Widget		parent;
+void create_week_menu(
+	Widget		parent)
 {
 	Arg		args[15];
 	int		n;
-	Widget		form, w;
+	Widget		form, w, w2;
 	Atom		closewindow;
 
 	build_week(FALSE, FALSE);
 
 	form = create_view_form(&shell, parent_form = parent, 'w',
-				week.canvas_xs, week.canvas_ys, "Week View");
+				week.canvas_xs, week.canvas_ys,_("Week View"));
 	if (!form) {
 		draw_week_calendar(NULL);
 		return;
 	}
-	XtAddCallback(form, XmNhelpCallback, help_callback, (XtPointer)"week");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"week");
 
 							/*-- buttons --*/
 	n = 0;
@@ -89,24 +90,26 @@ void create_week_menu(parent)
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		50);			n++;
-	w = XtCreateManagedWidget("Prev", xmPushButtonWidgetClass,
+	XtSetArg(args[n], XmNwidth,		60);			n++;
+	w = XtCreateManagedWidget(_("Prev"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, prev_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"week_prev");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			prev_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer) "week_prev");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	w);			n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		50);			n++;
-	w = XtCreateManagedWidget("Next", xmPushButtonWidgetClass,
+	XtSetArg(args[n], XmNwidth,		60);			n++;
+	w = XtCreateManagedWidget(_("Next"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback,next_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,    help_callback, (XtPointer)
-								"week_next");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			next_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer) "week_next");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -114,11 +117,12 @@ void create_week_menu(parent)
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"week_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer) "week_done");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
@@ -126,11 +130,12 @@ void create_week_menu(parent)
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback,help_callback, (XtPointer)"week");
-	XtAddCallback(w, XmNhelpCallback,    help_callback, (XtPointer)"week");
-
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"week");
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"week");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
@@ -138,11 +143,12 @@ void create_week_menu(parent)
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Edit", xmPushButtonWidgetClass,
+	w2 = XtCreateManagedWidget(_("Edit"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, edit_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"week_edit");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			edit_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer) "week_edit");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -152,11 +158,12 @@ void create_week_menu(parent)
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
 	XtSetArg(args[n], XmNsensitive,		!all_files_served());	n++;
-	w = XtCreateManagedWidget("Sync", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Sync"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, sync_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"week_sync");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			sync_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer) "week_sync");
 
 							/*--- infotext --- */
 	n = 0;
@@ -165,7 +172,7 @@ void create_week_menu(parent)
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_WIDGET);	n++;
-	XtSetArg(args[n], XmNbottomWidget,	w);			n++;
+	XtSetArg(args[n], XmNbottomWidget,	w2);			n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNalignment,         XmALIGNMENT_BEGINNING);	n++;
 #ifdef JAPAN
@@ -208,7 +215,7 @@ void create_week_menu(parent)
 	if (!parent) {
 		XtPopup(shell, XtGrabNone);
 		closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-		XmAddWMProtocolCallback(shell, closewindow,
+		XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
 				done_callback, (XtPointer)shell);
 	}
 	/*
@@ -223,11 +230,13 @@ void create_week_menu(parent)
  * Make it a bit larger for the shadow.
  */
 
-static void resize_canvas(shell, scroll, canvas, xs, ys)
-	Widget		shell;		/* shell with the DrawingArea */
-	Widget		scroll;		/* scrolling area around canvas */
-	Widget		canvas;		/* DrawingArea */
-	int		xs, ys;		/* new DrawingArea size */
+#if 0
+static void resize_canvas(
+	Widget		shell,		/* shell with the DrawingArea */
+	Widget		scroll,		/* scrolling area around canvas */
+	Widget		canvas,		/* DrawingArea */
+	int		xs,		/* new DrawingArea size */
+	int		ys)
 {
 	Dimension	sh_xs, sh_ys;	/* previous size of the shell */
 	Dimension	can_xs, can_ys;	/* previous size of the canvas */
@@ -241,6 +250,7 @@ static void resize_canvas(shell, scroll, canvas, xs, ys)
 	set_widget_size(shell,  sh_xs - can_xs + xs,
 				sh_ys - can_ys + ys);
 }
+#endif
 
 
 /*-------------------------------------------------- callbacks --------------*/
@@ -249,10 +259,10 @@ static void resize_canvas(shell, scroll, canvas, xs, ys)
  */
 
 /*ARGSUSED*/
-static void prev_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void prev_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	curr_week -= 7*86400;
 	build_week(FALSE, FALSE);
@@ -261,10 +271,10 @@ static void prev_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void next_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void next_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	curr_week += 7*86400;
 	build_week(FALSE, FALSE);
@@ -273,10 +283,10 @@ static void next_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (parent_form)
 		create_view('m');
@@ -286,10 +296,10 @@ static void done_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void edit_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void edit_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	create_list_popup(mainlist, curr_week, config.week_ndays*86400,
 					0, (struct entry *)0, 0, 0);
@@ -297,10 +307,10 @@ static void edit_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void sync_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void sync_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (!can_edit_appts())
 		return;
