@@ -223,8 +223,8 @@ void truncate_string(
 	int		sfont)		/* font of string */
 {
 	while (*string) {
-		len -= font[sfont]->per_char
-		       [*string - font[sfont]->min_char_or_byte2].width;
+		len -= font[sfont]->per_char[((unsigned char) *string) -
+					font[sfont]->min_char_or_byte2].width;
 		if (len < 0)
 			*string = 0;
 		else
