@@ -22,9 +22,10 @@
 #define XPOS(t)		(((t) - curr_yov) / 86400 * daysz)
 #define BOUND(t,a,b)	((t)<(a) ? (a) : (t)>(b) ? (b) : (t));
 
-
-static void draw_yov_strip_foreground(), draw_yov_strip_background();
-static void draw_bar();
+static void gen_yov			(void);
+static void draw_yov_strip_background	(int);
+static void draw_yov_strip_foreground	(int);
+static void draw_bar			(struct weeknode *, int, int, int);
 
 extern Display		*display;	/* everybody uses the same server */
 extern GC		jgc, gc;	/* graphic context, Japanese and std */
@@ -40,14 +41,10 @@ extern struct holiday	holiday[366];	/* info for each day, separate for */
 extern struct holiday	sm_holiday[366];/* full-line texts under, and small */
 extern short		monthlen[];	/* length of each month */
 extern char		*monthname[];	/* name of each month */
-
+extern char		*yovday_name[];
 static int		ndays;		/* number of days in year <curr_yov> */
 
 
-extern char *yovday_name[];
-extern char *monthname[];
-static void gen_yov();
-
 
 /*
  * for a given position on the canvas, identify the entry there and return
@@ -67,14 +64,17 @@ static void gen_yov();
  *   M_RIGHT	entry	time	trigg	pos/sz	near right edge, move end date
  */
 
-MOUSE locate_in_yov_calendar(epp, warn, time, trigger, xp, yp, xsp, ysp, xc,yc)
-	struct entry		**epp;		/* returned entry or 0 */
-	BOOL			*warn;		/* is *epp an n-days-ahead w?*/
-	time_t			*time;		/* if *epp=0, clicked where */
-	time_t			*trigger;	/* if *epp=0, entry trigger */
-	int			*xp,  *yp;	/* if M_INSIDE, rubber box */
-	int			*xsp, *ysp;	/* position and size */
-	int			xc, yc;		/* pixel pos clicked */
+MOUSE locate_in_yov_calendar(
+	struct entry		**epp,		/* returned entry or 0 */
+	BOOL			*warn,		/* is *epp an n-days-ahead w?*/
+	time_t			*time,		/* if *epp=0, clicked where */
+	time_t			*trigger,	/* if *epp=0, entry trigger */
+	int			*xp,		/* if M_INSIDE, rubber box */
+	int			*yp,
+	int			*xsp,		/* position and size */
+	int			*ysp,
+	int			xc,		/* pixel pos clicked */
+	int			yc)
 {
 	register struct config	*c = &config;
 	struct weeknode		*vert, *horz;	/* yov node scan pointers */
@@ -147,8 +147,8 @@ MOUSE locate_in_yov_calendar(epp, warn, time, trigger, xp, yp, xsp, ysp, xc,yc)
  * (all if null).
  */
 
-void draw_yov_calendar(region)
-	Region region;
+void draw_yov_calendar(
+	Region	region)
 {
 	if (!g_init_window(&yov, region))
 		return;
@@ -163,8 +163,8 @@ void draw_yov_calendar(region)
  * print PostScript yov calendar to file fp.
  */
 
-void print_yov_calendar(fp)
-	FILE	*fp;
+void print_yov_calendar(
+	FILE	*fp)
 {
 	time_t time = get_time();
 	struct tm *tm = time_to_tm(time);
@@ -186,7 +186,7 @@ void print_yov_calendar(fp)
  * draw the year overview, using low-level routines
  */
 
-static void gen_yov()
+static void gen_yov(void)
 {
 	register struct config	*c = &config;
 	struct tm		*tm;
@@ -233,7 +233,8 @@ static void gen_yov()
 	set_color(COL_WEEKDAY);
 	g_setfont(FONT_WHOUR);
 	for (i=0; i < 12; i++) {
-		g_drawtext(x, y, monthname[i], strlen(monthname[i]));
+		char *mn = _(monthname[i]);
+		g_drawtext(x, y, mn, strlen(mn));
 		x += (monthlen[i] + (i == 1 && !(year & 3))) * daysz;
 	}
 							/* day numbers/lines */
@@ -284,12 +285,11 @@ static void gen_yov()
  * following routine.
  */
 
-static void draw_yov_strip_background(strip)
-	int			strip;		/* day of the yov, < NDAYS */
+static void draw_yov_strip_background(
+	int			strip)		/* day of the yov, < NDAYS */
 {
 	register struct config	*c = &config;
 	char			buf[64];	/* holiday/user text buffer */
-	struct tm		*tm;		/* today's date as m/d/y */
 	char			*p;		/* temp for day name */
 	int			x, y;		/* upper left of day bk box */
 	int			ys;		/* height of bar line w/ gaps*/
@@ -315,7 +315,7 @@ static void draw_yov_strip_background(strip)
 		strncpy(buf, p, sizeof(buf));
 		buf[sizeof(buf)-1] = 0;
 	} else
-		strcpy(buf, "Own");
+		strcpy(buf, _("Own"));
 	truncate_string(buf, c->week_daywidth-2, FONT_WDAY);
 	g_setcolor(COL_WDAY);
 	g_setfont(FONT_WDAY);
@@ -334,8 +334,8 @@ static void draw_yov_strip_background(strip)
  * drawn by the caller.
  */
 
-static void draw_yov_strip_foreground(strip)
-	int			strip;		/* user strip number, 0=top */
+static void draw_yov_strip_foreground(
+	int			strip)		/* user strip number, 0=top */
 {
 	register struct config	*c = &config;
 	struct weeknode		*vert, *horz;	/* yov node scan pointers */
@@ -363,10 +363,11 @@ static void draw_yov_strip_foreground(strip)
  * draw one entry bar.
  */
 
-static void draw_bar(node, color, x, y)
-	struct weeknode		*node;		/* entry node to print */
-	int			color;		/* color, 0..7 */
-	int			x, y;		/* top left pos in canvas */
+static void draw_bar(
+	struct weeknode		*node,		/* entry node to print */
+	int			color,		/* color, 0..7 */
+	int			x,		/* top left pos in canvas */
+	int			y)
 {
 	register struct entry	*ep = node->entry;
 	register struct config	*c = &config;
